const thumbnails = document.querySelectorAll('.thumbnails img');
const overlay = document.querySelector('.overlay');
const overlayImage = overlay.querySelector('img');
const closeButton = overlay.querySelector('.close-btn');
const prevButton = overlay.querySelector('.prev-btn');
const nextButton = overlay.querySelector('.next-btn');
let currentImageIndex = 0;

thumbnails.forEach((thumbnail, index) => {
  thumbnail.addEventListener('click', () => {
    const fullImagePath = thumbnail.getAttribute('src').replace('thumbnails/', '');
    overlayImage.style.opacity = 0; // fade out the current image
    setTimeout(() => {
      overlayImage.setAttribute('src', fullImagePath);
      currentImageIndex = index;
      overlayImage.onload = () => {
        overlayImage.style.opacity = 1; // fade in the new image
      };
    }, 500); // wait for the fade out animation to complete
    overlay.style.display = 'block';
  });
});

closeButton.addEventListener('click', () => {
  overlay.style.display = 'none';
});

prevButton.addEventListener('click', () => {
  currentImageIndex = (currentImageIndex === 0) ? thumbnails.length - 1 : currentImageIndex - 1;
  const fullImagePath = thumbnails[currentImageIndex].getAttribute('src').replace('thumbnails/', '');
  overlayImage.style.opacity = 0; // fade out the current image
  setTimeout(() => {
    overlayImage.setAttribute('src', fullImagePath);
    overlayImage.onload = () => {
      overlayImage.style.opacity = 1; // fade in the new image
    };
  }, 500); // wait for the fade out animation to complete
});

nextButton.addEventListener('click', () => {
  currentImageIndex = (currentImageIndex === thumbnails.length - 1) ? 0 : currentImageIndex + 1;
  const fullImagePath = thumbnails[currentImageIndex].getAttribute('src').replace('thumbnails/', '');
  overlayImage.style.opacity = 0; // fade out the current image
  setTimeout(() => {
    overlayImage.setAttribute('src', fullImagePath);
    overlayImage.onload = () => {
      overlayImage.style.opacity = 1; // fade in the new image
    };
  }, 500); // wait for the fade out animation to complete
});

document.addEventListener('keydown', (event) => {
  if (event.key === 'ArrowLeft') {
    prevButton.click();
  } else if (event.key === 'ArrowRight') {
    nextButton.click();
  }
});

let touchstartX = 0;
let touchendX = 0;

overlay.addEventListener('touchstart', (event) => {
  touchstartX = event.changedTouches[0].screenX;
});

overlay.addEventListener('touchend', (event) => {
  touchendX = event.changedTouches[0].screenX;
  handleSwipeGesture();
});

function handleSwipeGesture() {
  if (touchendX < touchstartX) {
    nextButton.click();
  }

  if (touchendX > touchstartX) {
    prevButton.click();
  }
}





